@@ -18,14 +18,15 @@ typedef enum {GPuser_private,
               GPinstall,GPaddhelp,
               GPgrandO,
               GPbreak,GPnext,GPreturn,
-              GPfor,GPforstep,GPforstepvec,GPforprime,GPforvec,GPfordiv,
+              GPfor,GPforeach,GPforstep,GPforstepvec,GPforprime,GPforvec,
+              GPfordiv,GPfordivfactored,
               GPdoloop,
               GPlabel,
               GPglobal,GPlocal,GPlocalbitprec,GPlocalprec,
               GPif,
               GPprod,GPsum,GPsumdiv,GPprodeuler,
               GPuntil,GPwhile,GPwhilenull,
-              GPmakevec,GPmakemat,
+              GPmakevec,GPmakemat,GPmakevecsmall,
               GPvector,GPvectorsmall,GPvectorv,GPmatrix,
               GPiferr,
               GPinitfunc,GPcopyarg,
@@ -47,6 +48,8 @@ struct patchfunc_s
 {"next",NULL,Gvoid,0,GPnext},
 {"for","GGIG",Gnotype,(1<<Msemicolon),GPfor},
 {"fordiv",NULL,Gnotype,(1<<Msemicolon),GPfordiv},
+{"fordivfactored",NULL,Gnotype,(1<<Msemicolon),GPfordivfactored},
+{"foreach",NULL,Gnotype,(1<<Msemicolon),GPforeach},
 {"forstep","GIGGGG",Gnotype,(1<<Msemicolon),GPforstep},
 {"global",NULL,Gnotype,(1<<Msemicolon),GPglobal},
 {"if","GII",Gnotype,(1<<Msemicolon),GPif},
@@ -77,5 +80,6 @@ struct patchfunc_s
 {"_initfunc","",Gvoid,(1<<Msemicolon),GPinitfunc},
 {"_label",NULL,Gvoid,0,GPlabel},
 {"_makevec","*",Gnotype,(1<<Msemicolon),GPmakevec},
+{"_makevecsmall","*",Gnotype,(1<<Msemicolon),GPmakevecsmall},
 {"_whilenull","EI",Gnotype,(1<<Msemicolon),GPwhilenull},
 {NULL,NULL,0,0,0}};
